local L = LibStub("AceLocale-3.0"):GetLocale("ProximoGrid", true)
local defaultDB = {
	trinketUsed = {
		color = {1, 0, 0, 1},
		priority = 85
	},
};
StatusTrinketUsed = ProximoGridStatus.NewModule("StatusTrinketUsed", defaultDB);

StatusTrinketUsed.lastUpdate = 0;
StatusTrinketUsed.updateFrame = CreateFrame("frame");
StatusTrinketUsed.cache = {};
StatusTrinketUsed.header = L["Trinked Used"];
StatusTrinketUsed.options = {
	anySpellCast = {
		type = "group",
		name = "Trinket Used"],
		desc = L["Options for the status."],
		args = {
			color = {
				type = "color",
				name = L["Color"],
				desc = L["Color."],
				get = function()
					local tmpColor = StatusTrinketUsed.db.trinketUsed.color;
					return tmpColor[1], tmpColor[2], tmpColor[3], tmpColor[4]
				end,
				set = function(r, g, b, a)
					local tmpColor = StatusTrinketUsed.db.trinketUsed.color;
					tmpColor[1], tmpColor[2], tmpColor[3], tmpColor[4] = r, g, b, a or 1
				end,
				hasAlpha = false,
			},
			alpha = {
				type = "range",
				name = L["Alpha"],
				desc = L["Alpha."],
				get = function()
					return StatusTrinketUsed.db.trinketUsed.color[4];
				end,
				set = function(v)
					StatusTrinketUsed.db.trinketUsed.color[4] = v;
				end,
				min = 0,
				max = 1,
				step = 0.01
			},
			priority = {
				type = "range",
				name = L["Priority"],
				desc = L["Priority."],
				get = function()
					return StatusTrinketUsed.db.trinketUsed.priority;
				end,
				set = function(v)
					StatusTrinketUsed.db.trinketUsed.priority = v;
				end,
				min = 1,
				max = 99,
				step = 1
			}
		}
	},

}


function StatusTrinketUsed:COMBAT_LOG_EVENT_UNFILTERED(arg1, combatevent, sourceGUID, sourceName, sourceFlags, destGUID, destName, destFlags, spellId, spellName, spellSchool, missType, extraSpellName, extraSchool, auraType)
	-- Checks if someone that is not player controled is casting a spell
	if (combatevent == "SPELL_CAST_START" and bit.band(COMBATLOG_OBJECT_CONTROL_PLAYER, sourceFlags) ~= 0 and bit.band(COMBATLOG_OBJECT_AFFILIATION_OUTSIDER, sourceFlags) ~= 0) then
		if (not (spellId == 42292 or spellId == 5975)) then
			return;
		end
		local unitID;
		if (ProximoGrid:inArenaZone()) then
			for i=1, 5 do
				if (UnitGUID("arena"..i)==sourceGUID) then
					unitID = UnitGUID("arena"..i);
					break;
				end
			end
		else
			unitID = sourceGUID;
		end
		
		if (ProximoGrid:GetUnitFrameByUnitID(unitID)~=nil) then

			if (StatusTrinketUsed.cache[unitID] == nil) then
				StatusTrinketUsed.cache[unitID] = {};
			end
			StatusTrinketUsed.cache[unitID]["TrinketUsed"] = GetTime()+120;
			local icon;
			if (UnitFactionGroup("player")=="Alliance") then
				icon = "Interface\\Icons\\INV_Jewelry_TrinketPVP_02";
			else
				icon = "Interface\\Icons\\INV_Jewelry_TrinketPVP_01";
			end
			local r,g,b,a = StatusTrinketUsed.db.trinketUsed.color[1], StatusTrinketUsed.db.trinketUsed.color[2], StatusTrinketUsed.db.trinketUsed.color[3], StatusTrinketUsed.db.trinketUsed.color[4];
			if (StatusTrinketUsed:SendStatusGained(unitID, sourceName, "StatusTrinketTrinketUsed", StatusTrinketUsed.db.trinketUsed.priority, true, {["r"] = r,["g"] = g,["b"] = b, ["a"] = a}, L["Trinket Used"],  GetTime(), GetTime()+120, icon, 0, 0, 0)) then
				StatusUnitInfo:SendAnnouncement(string.format(L["Trinket used: %s"], sourceName), "announcementTrinketUsed");
			end
		end
	end
end



function StatusTrinketUsed:OnInitialize()
	StatusTrinketUsed:RegisterStatus("StatusTrinketTrinketUsed", L["Trinket Used "]);
	StatusTrinketUsed:RegisterAnnouncement("announcementTrinketUsed", L["Trinket Used "]);
end

function StatusTrinketUsed:OnEnable()
	StatusTrinketUsed:RegisterEvent("COMBAT_LOG_EVENT_UNFILTERED");
	StatusTrinketUsed.updateFrame:SetScript("OnUpdate", StatusTrinketUsed.OnUpdate);
end

function StatusTrinketUsed:OnDisable()
	StatusTrinketUsed:UnregisterEvent("COMBAT_LOG_EVENT_UNFILTERED");
	StatusTrinketUsed.frame:SetScript("OnUpdate", nil);
end



function StatusTrinketUsed:OnUpdate(self, elapsed)
	if (StatusTrinketUsed.lastUpdate+0.2<GetTime()) then
		for unitID, groups in pairs(StatusTrinketUsed.cache) do
			local counter = 0;
			local removed = false;
			for groupName, time in pairs(groups) do
				counter = counter + 1; 
				if (time < GetTime()) then
					StatusTrinketUsed.cache[unitID][groupName] = nil;
					StatusTrinketUsed:SendStatusLost(unitID, "StatusTrinketUsed"..groupName);
					removed = true;
				end
			end
			if (counter == 1 and removed) then
				StatusTrinketUsed.cache[unitID] = nil;
			end
		end
		StatusTrinketUsed.lastUpdate = GetTime();
	end
end