local L = LibStub("AceLocale-3.0"):GetLocale("ProximoGrid", true)
StatusUnitInfo = ProximoGridStatus.NewModule("StatusUnitInfo", {
	name = {
		useClassColors = true,
		color = {1, 1, 1, 1},
		priority = 50
	},
	class = {
		priority = 50
	},
	race = {
		priority = 50
	},
	announcements = {
		["announcementNewOpponent"] = {
			color = {1, 0, 0, 1},
			enableSound = true,
			soundFile = "GnomeExploration"
		}
	}
});



StatusUnitInfo.header = L["Unit Info"];
StatusUnitInfo.options = {
	name = {
		type = "group",
		name = L["Name"],
		desc = string.format(L["Options for the %s status."], L["Name"]),
		args = {
			useClassColor = {
				type = "toggle",
				name = L["Use Class Colors"],
				desc = L["Use blizzard's default class colors."],
				get = function()
					return StatusUnitInfo.db.name.useClassColors;
				end,
				set = function(v)
					StatusUnitInfo.db.name.useClassColors = v;
				end,
			},
			color = {
				type = "color",
				name = L["Color"],
				desc = L["The color that will be used if 'Use Class Colors' is not set."],
				get = function()
					local tmpColor = StatusUnitInfo.db.name.color;
					return tmpColor[1], tmpColor[2], tmpColor[3], tmpColor[4]
				end,
				set = function(r, g, b, a)
					local tmpColor = StatusUnitInfo.db.name.color;
					tmpColor[1], tmpColor[2], tmpColor[3], tmpColor[4] = r, g, b, a or 1
				end,
				hasAlpha = false,
			},
			alpha = {
				type = "range",
				name = L["Alpha"],
				desc = L["Alpha."],
				get = function()
					return StatusUnitInfo.db.name.color[4];
				end,
				set = function(v)
					StatusUnitInfo.db.name.color[4] = v;
				end,
				min = 0,
				max = 1,
				step = 0.01
			},
			priority = {
				type = "range",
				name = L["Priority"],
				desc = L["Priority."],
				get = function()
					return StatusUnitInfo.db.name.priority;
				end,
				set = function(v)
					StatusUnitInfo.db.name.priority = v;
				end,
				min = 1,
				max = 99,
				step = 1
			}
		}
	},
	class = {
		type = "group",
		name = L["Class"],
		desc = string.format(L["Options for the %s status."],L["Class"]),
		args = {
			priority = {
				type = "range",
				name = L["Priority"],
				desc = L["Priority."],
				get = function()
					return StatusUnitInfo.db.class.priority;
				end,
				set = function(v)
					StatusUnitInfo.db.class.priority = v;
				end,
				min = 1,
				max = 99,
				step = 1
			}
		}
	},
	race = {
		type = "group",
		name = L["Race"],
		desc = string.format(L["Options for the %s status."],L["Race"]),
		args = {
			priority = {
				type = "range",
				name = L["Priority"],
				desc = L["Priority."],
				get = function()
					return StatusUnitInfo.db.race.priority;
				end,
				set = function(v)
					StatusUnitInfo.db.race.priority = v;
				end,
				min = 1,
				max = 99,
				step = 1
			}
		}
	},
}

		
function StatusUnitInfo:PROXIMOGRID_UNIT_ADDED(unitID)
	local opponent = ProximoGrid.Opponents[unitID];
	local unitName = opponent.unitName;
	local unitClass = opponent.unitClass;
	local unitRace = opponent.unitRace;
	local unitSex = opponent.unitSex;
	local unitIsPet = opponent.unitIsPet;
	local unitCreatureType = opponent.unitCreatureType;

	local r, g, b, a;
	if (StatusUnitInfo.db.name.useClassColors) then
		if (not unitIsPet) then
			r, g, b, a = ProximoGrid:GetColor("class", unitClass);
		else
			r, g, b, a = ProximoGrid:GetColor("creature type", unitCreatureType);
		end
	else
		local tmpColor = StatusUnitInfo.db.name.color;
		r, g, b, a = tmpColor[1], tmpColor[2], tmpColor[3], tmpColor[4];
	end
	if (StatusUnitInfo:SendStatusGained(unitID, unitName, "statusName", StatusUnitInfo.db.name.priority, true, {["r"] = r,["g"] =g,["b"] =b, ["a"] = a}, unitName,  0, 0, nil, 0, 0, 0)) then
		StatusUnitInfo:SendAnnouncement(string.format(L["Enemy found: %s, %s (%s)"], unitName, unitClass, unitRace), "announcementNewOpponent");
	end
	if (unitClass~=nil) then
		if (not unitIsPet) then
			r, g, b, a = ProximoGrid:GetColor("class", unitClass);
		else
			r, g, b, a = ProximoGrid:GetColor("creature type", unitCreatureType);
		end
		StatusUnitInfo:SendStatusGained(unitID, unitName, "statusClass", StatusUnitInfo.db.class.priority, true, {["r"] = r,["g"] =g,["b"] =b, ["a"] = a}, unitClass,  0, 0, "Interface\\Glues\\CharacterCreate\\UI-CharacterCreate-Classes", 0, 0, 0);
	end
	local textString = unitSex;
	if (not unitIsPet) then
		r, g, b, a = ProximoGrid:GetColor("race", unitRace);
		textString = unitRace..";"..textString;
	else
		r, g, b, a = ProximoGrid:GetColor("creature type", unitCreatureType);
		textString = unitCreatureType;
	end

	StatusUnitInfo:SendStatusGained(unitID, unitName, "statusRace", StatusUnitInfo.db.race.priority, true, {["r"] = r,["g"] =g,["b"] =b, ["a"] = a}, textString,  0, 0, "Interface\\Glues\\CharacterCreate\\UI-CharacterCreate-Races", 0, 0, 0);

end

function StatusUnitInfo:OnInitialize()
	StatusUnitInfo:RegisterAnnouncement("announcementNewOpponent", L["New Opponent"])
	StatusUnitInfo:RegisterStatus("statusName", L["Unit Name"]);
	StatusUnitInfo:RegisterStatus("statusClass", L["Unit Class"]);
	StatusUnitInfo:RegisterStatus("statusRace", L["Unit Race"]);
	
end

function StatusUnitInfo:OnEnable()
	StatusUnitInfo:RegisterEvent("PROXIMOGRID_UNIT_ADDED");
end

function StatusUnitInfo:OnDisable()
	StatusUnitInfo:UnregisterEvent("PROXIMOGRID_UNIT_ADDED");
end